@@ -18,11 +18,30 @@ pub enum Error {
     },
 
     #[snafu(display("Could not parse mountinfo"))]
-    ParseMountInfo { source: crate::ParseMountInfoError },
+    #[cfg(target_os = "linux")]
+    ParseMountInfo {
+        source: crate::linux::ParseMountInfoError,
+    },
 
     #[snafu(display("Unexpected format"))]
     UnexpectedFormat,
 
     #[snafu(display("Error parsing device id"))]
     ParseDeviceId,
+
+    #[snafu(display("Failed to call service {service:?}"))]
+    ServiceCallFailed { service: &'static str },
+
+    #[snafu(display("Failed to read {key:?}"))]
+    MissingValue { key: &'static str },
+
+    #[snafu(display("Device layer not found"))]
+    DeviceLayerNotFound,
+
+    #[cfg(windows)]
+    #[snafu(display("Windows API call failed: {api}"))]
+    WindowsApiError {
+        source: windows::core::Error,
+        api: String,
+    },
 }
